@@ -2,6 +2,7 @@ import os.path
 
 import pytest
 
+
 mydir = os.path.dirname(__file__)
 
 
@@ -11,4 +12,4 @@ def pytest_runtest_setup(item):
             return
         mod = item.getparent(pytest.Module).obj
         if hasattr(mod, "hello"):
-            print("mod.hello {!r}".format(mod.hello))
+            print(f"mod.hello {mod.hello!r}")
