@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# mypy: allow-untyped-defs
 import pytest
 
 
 @pytest.fixture
 def arg1(request):
-    with pytest.raises(Exception):
+    with pytest.raises(pytest.FixtureLookupError):
         request.getfixturevalue("arg2")
