@@ -217,7 +217,7 @@ class TestParseIni:
 
     def test_confcutdir_default_without_configfile(self, pytester: Pytester) -> None:
         # If --confcutdir is not specified, and there is no configfile, default
-        # to the roothpath.
+        # to the rootpath.
         sub = pytester.mkdir("sub")
         os.chdir(sub)
         config = pytester.parseconfigure()
@@ -1243,7 +1243,7 @@ def test_disable_plugin_autoload(
 
     monkeypatch.setenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", "1")
     monkeypatch.setattr(importlib.metadata, "distributions", distributions)
-    monkeypatch.setitem(sys.modules, "mytestplugin", PseudoPlugin())  # type: ignore[misc]
+    monkeypatch.setitem(sys.modules, "mytestplugin", PseudoPlugin())
     config = pytester.parseconfig(*parse_args)
     has_loaded = config.pluginmanager.get_plugin("mytestplugin") is not None
     assert has_loaded == should_load
@@ -1740,7 +1740,7 @@ class TestOverrideIniArgs:
         )
         pytester.makepyfile(
             r"""
-            def test_overriden(pytestconfig):
+            def test_overridden(pytestconfig):
                 config_paths = pytestconfig.getini("paths")
                 print(config_paths)
                 for cpf in config_paths:
